@@ -271,19 +271,21 @@ c!λ81Wt7 X5ZڠFךw:o濭ky'f==s7+bvfgW/%辏%!yI{qջCĘ^1G16 1Ӵu+Q9M[
 	lu<S8}mnD?RWgE6c&gCp]U?":&eHLr-5wt% {)2E|+Ky+liو5Ȳ	kc^#^f[M
 Yc=?
 __CPAN_COMMON__ Storage_version6.swf
-CWSv  xڬXo;$,۲lZ
--[嘉)FXW\{衋9h/wݥlⓎZ^{hA/EOg{7 rvޛ=w`|.[)~EOǗ|8M=Q!.t%?cH6C/8p=^;bwzbp-P2m[q?	7ۿB1x]p"K<z# 
-7;a<~ŖBiDJFm$' P@@
-E>x-:4EA" ۱ +(:}캱oĸnٞ~]Nc{7=tDANMԵ/u'c	=y;-8VGfcc
-!>\|!l10z.f!Ҫ{ʧ	KK6Ể|1ue͘5@pHV2ay.YPZI-iji&k*I-kjy&uNSRǝE(;JDE$	|^ٓg*-_j>b77`
-Θ\ט/-)`J5RX9Yw@A&TR^o0uvTTsU UU	[8R΍)y5yGq*&,X[;hb,>iO*s)n1woSc.KCT-415<WmJ{\hlWDfL/r;*3G=Rz4'A2~rMd<O=0zp6%uOS")\,==W3WM01딻Ui,^k8"@ϩ4i1i|rq?<YHb<J4)e*wmO.+LfVZ;3[^
-7ߍ<φrycg{=Fq<1vV݋:`ݖpcmo' q9ЋDf2P:N!04@tf8}җD|t!EfP膇OPģW	l&++5(F^8G'~Ֆ`膑#	Cux޺c
-zRh]릗'\48֙7l>rFn$Zs{9wv'(qZ<75X+AA#L w
-CAZlD| v_/s.$n<u9MZH4O4֬h+Rl.lەMUjt!1¶k8.5UeQ#][\g7S_6+J祶<XL[9ِͮ>e﹒ad1WZcȲy;Y%# )dV3Vz+i#8c)z+ۣaj(oYV-[干N.'yFFm/PTYV@6 ~uF1L⠫@MBVV
-kVZre[eX\ݞh%"\\?Pws5_ΤgMZo)Yj.wyZ(j@Nf̤
-tE4The45x%uYqOr+oSq.ɲ._t^o8ߐsI49 盙f6U h$]ݵ8FA8]#^HjM[p;w){J7΅q5R\@|"a	,%akm >m(U8]ULYK
-{*&$>S;xPY.,˿*ԥ\,KP@%|vL<
-|NGoR6|im~f{y߀x/gİ8   p\
+CWS  xڬXKo>$+q	cē8ddZ@:k& M-]L(R )'꦳]A7EWtٟЅ{ uyϹ}w};~eOKW&>qr}Ip
+go	Α>o½	owK<~`8Jv\?Dpw$^pCgnķ1Dl0CzĊx(
+GEa@7bnd*<؎
+ƴbiC#£F/$
+NFa&!8α}un˰^Ct7aM16Q|w=칉or/vqXCWg6y,Q:wv:OCpr{0'QfOb*qlG;SM0ppﻘXK&:PQKESkFGڤ,d	QbMwȩZV\jEQ+sTQ\jUQs0Kbw] ,#AO.[yr%}m~6t-
+} JuEů\=6C_򯷹Pzh_JyׄBt]R M\y!ɳQyq7:Sr7q88oΫ;S0YbtBd|6$=emG{)iB*7nqOqn%8.OլL9W,ƖOkxEx4˅~ ӮJ="乢W+k	R}!`^e+/2YfSBQ4ҫR:ӫY8Sz/D{@KN|PFpaĠ6a;R$FF2?K^Ou*ϥ¶':dk<3'e~}dU>V[t-ZCٲY>LbwOACh%zn8A;;)@a/tf7ހErVNuqp11@tf8^xp,9{vPFGO%(@L
+#E-tr_yN!=
+9F}
+C7Q-`鏂n⅁(@n;CBm(')~~A[|RrFnw>l{3aD|?;N>
+  R]zÛQR7C-"h	CmJ&gX&qEXд4IKV"X Ko.ܶoW2eN"Q4n0bq`ǡح"tLsͬoX
+'3_Z?r<VXK<m9e<7ZMi,lNW0 un#;571`K9c@~òQޟp̳)\N`ښ/Qَ@<P֮K9E"qʳ¡92u*9DJBڐT_H{|0O	V#ab
+E}^
+tC&V߮|)M]
+&ݜ5ԟuWA|IȪd|0]."{VlqyDW9r1:S	+BjOPM}[2brѻ]ٜ8,GA=-/,YB锄ԍp<)X͟@<䝲
+頖y,] TC# >nsEP|!Y,4\,K"!B&d$=;M(JtAPK$oZ6|em~vgyݴ 9[D/2N    'd
 __CPAN_COMMON__ Storage_version8.swf
 CWS   xڬn+8V8N$v1iv2BmɐhPJRvUvBhWbtS
 {IQ4Iz!{{P?@ Mr<_wzs[w}`zn_ӫ&MnsA*u=mhznM,
@@ -376,7 +378,7 @@ been tested on almost every modern browser, including:
     - Konqueror 3.4+
     - Opera 8.5+
 
-Note that some widgets and features may not preform exactly the same on every
+Note that some widgets and features may not perform exactly the same on every
 browser due to browser implementation differences.
 
 For those looking to use Dojo in non-browser environments, please see "Working
@@ -439,7 +441,7 @@ repository are available at:
 
 Anonymous Subversion access is also available:
 
-    %> svn co http://svn.dojootoolkit.org/dojo/trunk/ dojo
+    %> svn co http://svn.dojotoolkit.org/dojo/trunk/ dojo
 
 Each of these sources will include some extra directories not included in the
 pre-packaged editions, including command-line tests and build tools for
@@ -487,7 +489,7 @@ could then make a profile build using it by doing:
     %> ant -Dprofile=test -Ddocless=true release intern-strings
 
 If the build is successful, your newly minted and compressed  profile build will
-be placed in [dojo]/releae/dojo/
+be placed in [dojo]/release/dojo/
 
 -------------------------------------------------------------------------------
 Copyright (c) 2004-2006, The Dojo Foundation, All Rights Reserved
